import { getButtons } from '../utility/utility';

export default function generateTemplateMarkup(card, type, speech, quickreplyMarkup, customName) {
  switch (type) {
    case 'card':
      return getCarouselMarkup(card, type, speech, quickreplyMarkup, customName);
    case 'image':
      return getImageMarkup(card, speech, quickreplyMarkup, customName);
    case 'carousel':
      return getCarouselMarkup(card, type, speech, quickreplyMarkup, customName);
    case 'button':
      return getButtonMarkup(card, speech, quickreplyMarkup, customName);
    case 'hook':
      return getButtonMarkup(card, speech, quickreplyMarkup, customName);
    case 'list':
      return getListMarkup(card, speech, quickreplyMarkup, customName);
    case 'quickreply':
      return getQuickreplyMarkup(card, speech, quickreplyMarkup);
    default:
      return '';
  }
}

function getImageMarkup(card, speech, quickreplyMarkup, customName) {
  var image = card.image;

  var speechResponse = speech ? speech : '';
  var quickreply = quickreplyMarkup ? quickreplyMarkup : '';
  var naming = customName ? customName : '';
  return '<div class="panel panel-default button-div border-radius-top-20" data-element="true" data-customTemplate="' + naming + '" data-speech="' + speechResponse + '"  data-image="' + image + '"> <div class="panel-heading card-image"> <img src="' + image + '" class="img-responsive"> </div>\n  </div> ' + quickreply + ' ';
}

function getCarouselMarkup(card, type, speech, quickreplyMarkup, customName) {
  var title = card.title,
      subtitle = card.subtitle,
      image = card.image,
      keyName = card.keyName;

  var quickreply = quickreplyMarkup ? quickreplyMarkup : '';
  var speechResponse = speech ? speech : '';
  var naming = customName ? customName : '';
  if (type === 'card') {
    if (!keyName) {
      return '<div class="panel panel-default button-div border-radius-top-20" data-element="true" data-customTemplate="' + naming + '"  data-title="' + title + '" data-subTitle="' + subtitle + '" data-image="' + image + '" data-speech="' + speechResponse + '"><div class="panel-heading card-image"> <img src=' + image + ' class="img-responsive"> </div><div class="panel-body"><div class="row"><div class="col-xs-12 buttondesign"><h5 class="uob-amex card-title" style="font-weight: bold;">' + title + ' </h5>\n      <p class="account-number">' + subtitle + '</p></div></div></div>' + getButtons(card) + '</div>  ' + quickreply;
    }
  }
  return '{{#each ' + (keyName ? keyName : 'carousel') + ' }}<div class="panel panel-default button-div border-radius-top-20" data-element="true" data-customTemplate="' + naming + '" data-title="' + title + '" data-subTitle="' + subtitle + '" data-image="' + image + '" data-speech="' + speechResponse + '"><div class="panel-heading card-image"> <img src=' + image + ' class="img-responsive"> </div><div class="panel-body"><div class="row"><div class="col-xs-12 buttondesign"><h5 class="uob-amex card-title" style="font-weight: bold;">' + title + ' </h5>\n  <p class="account-number">' + subtitle + '</p></div></div></div>' + getButtons(card) + '</div>\n  {{/each}} ' + quickreply;
}
function getButtonMarkup(card, speech, quickreplyMarkup, customName) {
  var title = card.title;

  var speechResponse = speech ? speech : '';
  var quickreply = quickreplyMarkup ? quickreplyMarkup : '';
  var naming = customName ? customName : '';
  return '<div class="panel panel-default button-div border-radius-top-2" data-element="true" data-customTemplate=" ' + naming + ' " data-title=" ' + title + ' " data-speech=" ' + speechResponse + ' ">\n  <div class="panel-body"> \n  <div class="row"> \n  <div class="col-xs-12 buttondesign"> \n  <h5 class="uob-amex card-title" style="font-weight: bold;">' + title + '\n  </h5> \n  </div>\n  </div> \n  </div> \n  ' + getButtons(card) + '\n </div> ' + quickreply + ' ';
}
function getListMarkup(content, speech, quickreplyMarkup, customName) {
  var firstListObject = content.style === 'compact' ? content.list[0] : content.list[1];
  var quickreply = quickreplyMarkup ? quickreplyMarkup : '';
  var title = firstListObject.title,
      subtitle = firstListObject.subtitle,
      image = firstListObject.image;

  var keyName = content.keyName || 'list';
  var showMore = content.showMore;
  var speechResponse = speech ? speech : '';
  var naming = customName ? customName : '';
  var template = '<div class="panel panel-default list-custom-template">' + '{{#each ' + keyName + '}}' + '<div class="panel-body" data-element="true" data-customTemplate="' + naming + '"+ data-header="' + (content.header.title ? content.header.title : '') + '" data-title="' + title + '" data-subTitle="' + subtitle + '" data-image="' + image + '" data-speech="' + speechResponse + '">' + '<div class="row">' + '<div class="col-md-7 col-xs-7">' + '<h4 class="list-heading">' + title + '</h4>' + '<p class="list-subtitle">' + subtitle + '</p>' + getButtons(firstListObject) + '</div>' + '<div class="col-md-5 col-xs-5 text-right"> <img width="100" src="' + image + '"class="img-responsive pull-right"> </div>' + '</div>' + '</div>' + '{{/each}}';

  if (showMore) {
    template += getButtons(showMore, 'buttons');
  }
  template += '</div> ' + quickreply;
  return template;
}

function getQuickreplyMarkup(message) {
  var templateMarkup = message.templateMarkup,
      quick_replies = message.quick_replies,
      quickreply_templateMarkup = message.quickreply_templateMarkup;

  var template = '';
  quick_replies.map(function (each) {
    var keyName = each.keyName,
        title = each.title,
        payload = each.payload,
        dynamicTemplate = each.dynamicTemplate;

    keyName = keyName ? '{{#each ' + keyName + '}}' : '';
    var datapayload = ' data-payload=\'' + payload + '\'';

    if (dynamicTemplate) {
      template += keyName + '<button type="button" data-type="Postback" class="btn btn-primary btn-sm btn-block" id="button{{@index}}" data-buttons="true" data-button="true" data-title="' + title + '" data-quick-type="text"' + datapayload + '>' + title + '</button>' + ('' + (keyName === '' ? '' : '{{/each}}'));
    } else {
      template += '<button type="button" data-type="Postback" class="btn btn-primary btn-sm btn-block" id="button{{@index}}" data-buttons="true" data-button="true" data-title="' + title + '" data-quick-type="text"' + datapayload + '>' + title + '</button>';
    }

    return template;
  });
  if (templateMarkup) message['templateMarkup'] = templateMarkup.slice(0, templateMarkup.indexOf(quickreply_templateMarkup)) + template;
  return template;
}