function textValidation(content) {
  if (content) {
    return true;
  }
  return false;
}

function ImageValidation(content) {
  if (content.image) {
    return true;
  }
  return false;
}

function cardValidation(content, type) {
  if (!content.image && !content.subtitle && !content.title) {
    if (content.buttons.length) {
      return isButtonsValid(content.buttons, type);
    }
    return false;
  }
  return true;
}

function buttonValidation(content, type) {
  if (!content.title) {
    if (content.buttons.length) {
      return isButtonsValid(content.buttons, type);
    }
    return false;
  }
  return true;
}

function isButtonsValid(buttons, type) {
  var fieldName = type === 'list' || type === 'button' ? 'payload' : 'postback';
  var contentsButtons = buttons.filter(function (button) {
    if (button.title || button[fieldName]) {
      return button;
    }
  });
  if (contentsButtons.length) {
    return contentsButtons;
  }
  return false;
}

function quickReplyValidation(quick_replies) {
  if (!quick_replies) {
    return [];
  }
  return quick_replies.filter(function (replies) {
    if (replies.title || replies.payload) {
      return replies;
    }
  });
}
function HookValidation(content, type, intent, payload) {
  if (content == '') {
    return false;
  }
  return true;
}
function customTemplateValidation(content, name) {
  if (content.trim().length > 0 && name && name.trim().length > 0) {
    return true;
  }
  return false;
}
function dynamicTemplateValidation(message) {
  if (message.title === 'Custom') {
    return customTemplateValidation(message.content, message.name);
  } else {
    return textValidation(message.content);
  }
}
function answerValidation(answer, onSave) {
  if (!answer.messages) {
    console.log('Old Template not supported');
    return false;
  }

  var messages = answer.messages;

  var newMessages = messages.filter(function (message) {
    switch (message.type) {
      case 'list':
        if (message.content.list[0].title || message.content.list[0].image) {
          return true;
        }
        var list = message.content.list.slice(1);
        for (var i = 0; i < list.length; i++) {
          if (cardValidation(list[i], message.type)) {
            return true;
          }
        }
        return false;
      case 'rblist':
        if (message.content.title || message.content.image) {
          return true;
        }
        return false;
      case 'carousel':
        var content = message.type === 'carousel' ? message.content : message.content.list;
        for (var _i = 0; _i < content.length; _i++) {
          if (cardValidation(content[_i], message.type)) {
            return true;
          }
        }
        return false;
      case 'card':
        return cardValidation(message.content, message.type);
      case 'image':
        return ImageValidation(message.content);
      case 'button':
        return buttonValidation(message.content, message.type);
      case 'hook':
        return HookValidation(message.content, message.type, message.intent, message.payload);
      case 'text':
      case 'ssml':
        return textValidation(message.content);
      case 'dynamic':
        return dynamicTemplateValidation(message);
      default:
        break;
    }
  });
  if (onSave) {
    newMessages = carouselFilter(newMessages);
    newMessages = listFilter(newMessages);
    newMessages = buttonFilter(newMessages);
  }
  return newMessages;
}
function carouselFilter(oldMessages) {
  var messages = JSON.parse(JSON.stringify(oldMessages));
  var validCarouselIndex = [];
  messages.forEach(function (message) {
    if (message.type === 'carousel') {
      message.content.forEach(function (carousel, index) {
        if (cardValidation(carousel, 'carousel')) {
          validCarouselIndex.push(index);
        }
      });
      message.content = message.content.filter(function (card, index) {
        if (validCarouselIndex.indexOf(index) !== -1) {
          return card;
        }
      });
      message.content.forEach(function (content) {
        if (content.buttons.length) {
          var validButtons = isButtonsValid(content.buttons, 'carousel');
          content.buttons = validButtons ? validButtons : [];
        }
      });
      validCarouselIndex = [];
    }
  });
  return messages;
}
function listFilter(oldMessages) {
  var messages = JSON.parse(JSON.stringify(oldMessages));
  var validListIndex = [];
  messages.forEach(function (message) {
    if (message.type === 'list' || message.type === 'rblist') {
      message.content.list.forEach(function (content, index) {
        if (index && cardValidation(content, 'list')) {
          validListIndex.push(index);
        }
      });
      var list = [].concat(message.content.list.slice(0, 2));
      message.content.list = message.content.list.filter(function (list, index) {
        if (index === 0) {
          return list;
        }
        if (validListIndex.indexOf(index) !== -1) {
          return list;
        }
      });
      message.content.list.forEach(function (list, index) {
        if (index && list.buttons.length) {
          var validButtons = isButtonsValid(list.buttons, 'list');
          list.buttons = validButtons ? validButtons : [];
        }
      });
      if (message.content.list.slice(1).length === 0) {
        message.content.list = [].concat(list);
      }
      validListIndex = [];
    }
  });
  return messages;
}

function buttonFilter(oldMessages) {
  var messages = JSON.parse(JSON.stringify(oldMessages));
  messages.forEach(function (message) {
    if (message.type !== 'text' && message.type !== 'ssml' && message.type !== 'image') {
      var buttons = message.content.buttons;

      if (message.type !== 'list' && message.type !== 'rblist' && message.type !== 'carousel' && buttons && buttons.length) {
        var buttonsValid = isButtonsValid(buttons, message.type);
        message.content.buttons = buttonsValid ? buttonsValid : [];
      }
    }
  });
  return messages;
}

export default {
  answerValidation: answerValidation,
  quickReplyValidation: quickReplyValidation
};