import _regeneratorRuntime from 'babel-runtime/regenerator';

var _this = this;

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

import { addTemplateUrl, getTemplateUrl } from './config';
import cookie from 'react-cookies';
import axios from 'axios';
import { toast } from 'react-toastify';
import { networkMessages } from './utility';
import { useState } from 'react';

export var addTemplate = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(data) {
    var cookies, userToken, xsrfToken, url, type, isEdit, result;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            cookies = cookie.loadAll();
            userToken = cookies.userToken, xsrfToken = cookies.csrfToken;
            url = void 0, type = void 0, isEdit = data.templateIntId;


            if (isEdit) {
              type = 'PUT';
              url = addTemplateUrl + '/' + isEdit;
            } else {
              type = 'POST';
              url = addTemplateUrl;
            }

            _context.next = 6;
            return axios({
              method: type,
              url: url,
              credentials: 'same-origin',
              headers: {
                'content-type': 'application/json',
                'X-Auth-Token': userToken,
                'X-CSRF-Token': xsrfToken
              },
              data: JSON.stringify(data)
            }).then(function (response) {
              if (response.status === 200) {
                return response.data;
              }
            }).then(function (response) {
              if (response.code === '200') {
                if (isEdit) {
                  toast.success(networkMessages['templateEditSuccess']);
                } else {
                  toast.success(networkMessages['templateAddSuccess']);
                }
                return true;
              }
              if (response.mCode === 'COMMON_EXCEPTION') {
                toast.error(networkMessages['templateNameExit']);
              }
              return false;
            }).catch(function (error) {
              console.log('error saving template');
              console.log(error);
              if (error.response.status === 403 || error.status.code === 401) {
                toast.error(networkMessages['sessionExpired']);
              }
              return false;
            });

          case 6:
            result = _context.sent;
            return _context.abrupt('return', result);

          case 8:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, _this);
  }));

  return function addTemplate(_x) {
    return _ref.apply(this, arguments);
  };
}();

export var getTemplateByCode = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(templateCode, allowTemplateMarkup) {
    var url, cookies, userToken, xsrfToken, result;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            url = getTemplateUrl + '/' + templateCode + '?templateLang=en';
            cookies = cookie.loadAll();
            userToken = cookies.userToken, xsrfToken = cookies.csrfToken;
            _context2.next = 5;
            return axios({
              method: 'GET',
              url: url,
              credentials: 'same-origin',
              headers: {
                'content-type': 'application/json',
                'X-Auth-Token': userToken,
                'X-CSRF-Token': xsrfToken
              }
            }).then(function (response) {
              if (response.status === 200) {
                return response.data;
              }
            }).then(function (response) {
              if (response.code === '200' || response.statusCode === '200') {
                var _ref3 = response.response ? response.response : response,
                    templateModel = _ref3.templateModel;

                var messages = void 0;
                if (templateModel && templateModel.templateJson) {
                  var templateJson = allowTemplateMarkup ? [] : JSON.parse(templateModel.templateJson);
                  if (templateJson[0] && templateJson[0].messages) {
                    messages = templateJson[0].messages;
                  }
                }
                if (messages || allowTemplateMarkup) {
                  var _result = {
                    templateIntId: templateModel.templateIntId,
                    templateMarkup: templateModel.templateMarkup,
                    templateCode: templateModel.templateCode
                  };
                  if (!allowTemplateMarkup) {
                    _result.answer = JSON.parse(templateModel.templateJson);
                  }
                  return _result;
                } else {
                  toast.error(networkMessages['manageTemplatesV1']);
                }
              } else {
                toast.error(networkMessages['templateNotFound']);
              }
            }).catch(function (error) {
              console.error(error);
              if (error.status.code === 401 || error.status.code === 403) {
                toast.error(networkMessages['sessionExpired']);
              }
              throw new Error('error in handling templates');
            });

          case 5:
            result = _context2.sent;
            return _context2.abrupt('return', result);

          case 7:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, _this);
  }));

  return function getTemplateByCode(_x2, _x3) {
    return _ref2.apply(this, arguments);
  };
}();

export var generateS3Url = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(S3url, xcsrf_token, imageId, oldImageId, image) {
    var url, formData, result, response;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            url = S3url + '/' + imageId + '?oldImage=' + oldImageId;
            formData = new FormData();

            formData.append('file', image);
            result = '';
            _context3.next = 6;
            return axios({
              method: 'POST',
              url: url,
              data: formData,
              withCredentials: true,
              headers: {
                'Content-Type': 'multipart/form-data;boundary=12345',
                'X-CSRF-Token': xcsrf_token
              }
            });

          case 6:
            response = _context3.sent;

            if (response.data.success) {
              result = response.data.response.signedUrl;
            } else if (response.status === 403 || response.status === 401) {
              toast.error(networkMessages['sessionExpired']);
            } else {
              toast.error(response.data.statusMsg);
            }
            return _context3.abrupt('return', result);

          case 9:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, _this);
  }));

  return function generateS3Url(_x4, _x5, _x6, _x7, _x8) {
    return _ref4.apply(this, arguments);
  };
}();