import _regeneratorRuntime from 'babel-runtime/regenerator';

var _this = this;

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

import { v1 } from 'uuid';

import { RESPONSE_TYPES } from '../components/TemplateResponseTypes';
import { addTemplate, getTemplateByCode } from './templateAction';

export var isDynamicContent = function isDynamicContent(string) {
  return string.indexOf('{{') >= 0 && string.indexOf('}}') >= 0;
};

export var getSanitizedString = function getSanitizedString(string) {
  var regExp = /\{([^)]+)\}/;
  var sanitizedString = string.match(regExp)[0];
  return sanitizedString.replace(/[{{}}]/g, ' ').replace(/-/g, ' ');
};

function convertAttributesToString(attributes, buttons) {
  var buttonAttributes = '';
  Object.keys(attributes).forEach(function (key) {
    if (attributes[key].key === 'data-buttons') {
      buttonAttributes += buttons ? 'data-buttons=\'' + attributes[key].value + '\' ' : 'data-button=\'' + attributes[key].value + '\' ';
    } else {
      buttonAttributes += attributes[key].key + '=\'' + attributes[key].value + '\' ';
    }
  });
  return buttonAttributes;
}

export var getButtons = function getButtons(card, buttons) {
  if (card.buttons.length > 0) {
    var buttonWithAttributes = ' ';
    card.buttons.forEach(function (button) {
      var attributes = button.attributes;
      if (attributes) {
        buttonWithAttributes += "<button data-payload='" + button.payload + "' data-type='" + button.type + "' " + convertAttributesToString(button.attributes, buttons) + '>' + button.title + '</button>';
      }
    });
    return buttonWithAttributes;
  } else if (card.buttons.length === 0) {
    return '';
  }
};

export var getParam = function getParam(data) {
  var params = new URLSearchParams(window.location.search);
  var value = params.get(data);
  return value;
};

export var isJsonValid = function isJsonValid(content) {
  try {
    var templateJson = JSON.parse(content);
    if (templateJson.length === 0 || !templateJson[0].messages) {
      return false;
    }
  } catch (err) {
    return false;
  }
  return true;
};
export var sanitizeJSON = function sanitizeJSON(answers) {
  var __answers = JSON.parse(JSON.stringify(answers));
  __answers.forEach(function (answer) {
    delete answer.save;
    answer.messages.forEach(function (message) {
      delete message['icon'];
      delete message['key'];
      if (!message.dynamicTemplate) {
        delete message['templateMarkup'];
      }
      if (!message['dynamicTemplate'] && !message.base != 'baseTemplate') {
        delete message['id'];
      }
      if (message.type === 'rblist' || message.type === 'carousel' || message.type === 'list') {
        var content = message.type === 'carousel' ? message.content : message.content.list;
        content.forEach(function (item) {
          delete item['key'];
        });
      }
    });
  });
  return __answers;
};

export var desanitizeJSON = function desanitizeJSON(answers, cust_seg) {
  var __answers = JSON.parse(JSON.stringify(answers));
  __answers.forEach(function (answer) {
    var messages = answer.messages;

    messages.forEach(function (message, msgIndex) {
      var index = 0;
      var key = Math.floor(Math.random() * 1000) + 1;
      while (true) {
        if (msgIndex === 0 || index === msgIndex) {
          message['key'] = key;
          break;
        } else if (messages[index].key !== key) {
          ++index;
        } else {
          key = Math.floor(Math.random() * 1000) + 1;
          index = 0;
        }
      }
      if (message.dynamicTemplate && message.base === 'carousel' && message.content.list) {
        message.content = [].concat(message.content.list);
      }
    });
  });
  return __answers;
};

export var getUniqueId = function getUniqueId() {
  var date = new Date();
  var components = [date.getYear(), date.getMonth(), date.getDate(), date.getHours(), date.getMinutes(), date.getSeconds(), date.getMilliseconds()];
  return components.join('');
};

var getTemplateMarkup = function getTemplateMarkup(templateType) {
  var templateMarkup = RESPONSE_TYPES.filter(function (template) {
    return template.type === templateType;
  });
  if (templateMarkup.length) {
    return templateMarkup[0].templateMarkup;
  }
  return '';
};

export var generateTemplateData = function generateTemplateData(_ref) {
  var answer = _ref.answer,
      currentIndex = _ref.currentIndex,
      tmpName = _ref.tmpName,
      templateIntId = _ref.templateIntId,
      category = _ref.category;

  var template = {
    templateName: tmpName,
    templateCode: tmpName,
    templateCategory: category ? category : tmpName,
    templateMarkup: getTemplateMarkup(answer[currentIndex].messages[0].type),
    templateType: 'RS',
    templateJson: JSON.stringify(answer),
    channelType: answer[currentIndex].channel === 'default' ? 'ap' : answer[currentIndex].channel,
    templateId: getUniqueId(),
    templateLang: 'en'
  };
  if (templateIntId) {
    template.templateIntId = templateIntId;
  }
  return template;
};

export var saveTemplate = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref2) {
    var answer = _ref2.answer,
        currentIndex = _ref2.currentIndex,
        tmpName = _ref2.tmpName,
        templateIntId = _ref2.templateIntId,
        saveCustomTemplate = _ref2.saveCustomTemplate,
        customData = _ref2.customData,
        dynamicTemplates = _ref2.dynamicTemplates,
        category = _ref2.category;

    var templateData, _result, result;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            templateData = void 0;

            if (!saveCustomTemplate) {
              _context.next = 6;
              break;
            }

            _context.next = 4;
            return addTemplate(customData);

          case 4:
            _result = _context.sent;
            return _context.abrupt('return', _result);

          case 6:
            answer.forEach(function (ans) {
              ans.messages.forEach(function (message) {
                if (message.type === 'dynamic' && message.dynamicTemplate) {
                  var _templateData = {};
                  if (message.base === 'baseTemplate') {
                    var selectedTemplateType = 'RS';
                    _templateData.templateJson = message.content;
                    _templateData.templateType = selectedTemplateType;
                    _templateData.templateMarkup = message.templateMarkup;
                    _templateData.channelType = ans.channel === 'default' ? 'ap' : ans.channel;
                    _templateData.voiceText = '';
                    _templateData.templateId = _templateData.templateCode = message.id;
                    _templateData.templateName = v1('template');
                    _templateData.templateCategory = 'CUSTOM';
                    _templateData.templateLang = 'en';
                    if (dynamicTemplates[message.id] && dynamicTemplates[message.id].templateIntId) {
                      _templateData.templateIntId = dynamicTemplates[message.id].templateIntId;
                    }
                    addTemplate(_templateData);
                    message.html = message.content;
                    message.content = {};
                  } else {
                    var _selectedTemplateType = void 0; //Change based on message.base - LT, ITSB, I, TB
                    _templateData.templateJson = _templateData.templateMarkup = message.templateMarkup;
                    _templateData.channelType = ans.channel === 'default' ? 'ap' : ans.channel;
                    _templateData.voiceText = '';
                    _templateData.templateId = _templateData.templateCode = message.id;
                    _templateData.templateName = v1('template');
                    _templateData.templateCategory = 'CUSTOM';
                    _templateData.templateLang = 'en';
                    switch (message.base) {
                      case 'image':
                        _selectedTemplateType = 'I';
                        break;
                      case 'list':
                        _selectedTemplateType = 'LT';
                        break;
                      case 'carousel':
                      case 'button':
                        _selectedTemplateType = 'ITSB';
                        break;
                      default:
                        break;
                    }
                    _templateData.templateType = _selectedTemplateType;
                    if (dynamicTemplates[message.id] && dynamicTemplates[message.id].templateIntId) {
                      _templateData.templateIntId = dynamicTemplates[message.id].templateIntId;
                    }
                    addTemplate(_templateData);
                  }
                }
              });
            });
            templateData = generateTemplateData({
              answer: answer,
              currentIndex: currentIndex,
              tmpName: tmpName,
              templateIntId: templateIntId,
              category: category
            });
            _context.next = 10;
            return addTemplate(templateData);

          case 10:
            result = _context.sent;
            return _context.abrupt('return', result);

          case 12:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, _this);
  }));

  return function saveTemplate(_x) {
    return _ref3.apply(this, arguments);
  };
}();

export var getTemplates = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(templateCode) {
    var _ref5, answer, templateIntId, dynamicTemplates, promises, templateData;

    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.prev = 0;
            _context3.next = 3;
            return getTemplateByCode(templateCode);

          case 3:
            _ref5 = _context3.sent;
            answer = _ref5.answer;
            templateIntId = _ref5.templateIntId;
            dynamicTemplates = {};
            promises = [];

            answer.forEach(function (ans) {
              ans.messages.forEach(function () {
                var _ref6 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(message) {
                  var result;
                  return _regeneratorRuntime.wrap(function _callee2$(_context2) {
                    while (1) {
                      switch (_context2.prev = _context2.next) {
                        case 0:
                          if (message.dynamicTemplate) {
                            result = getTemplateByCode(message.id, true);

                            promises.push(result);
                          }

                        case 1:
                        case 'end':
                          return _context2.stop();
                      }
                    }
                  }, _callee2, _this);
                }));

                return function (_x3) {
                  return _ref6.apply(this, arguments);
                };
              }());
            });
            _context3.next = 11;
            return Promise.all(promises);

          case 11:
            templateData = _context3.sent;

            templateData.forEach(function (data) {
              dynamicTemplates[data.templateCode] = {
                templateIntId: data.templateIntId,
                templateMarkup: data.templateMarkup
              };
            });
            answer.forEach(function (ans) {
              ans.messages.forEach(function (message) {
                if (message.dynamicTemplate && message.title === 'Custom' && dynamicTemplates[message.id] && dynamicTemplates[message.id].templateMarkup) {
                  message.content = dynamicTemplates[message.id].templateMarkup;
                }
              });
            });
            return _context3.abrupt('return', {
              answer: answer,
              templateIntId: templateIntId,
              dynamicTemplates: dynamicTemplates
            });

          case 17:
            _context3.prev = 17;
            _context3.t0 = _context3['catch'](0);

            console.error(_context3.t0);
            throw new Error(_context3.t0);

          case 21:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, _this, [[0, 17]]);
  }));

  return function getTemplates(_x2) {
    return _ref4.apply(this, arguments);
  };
}();

export var networkMessages = {
  templateAddSuccess: 'Template saved success',
  templateEditSuccess: 'Template update success',
  templateNameExit: 'Template Name already saved, please try with different name',
  sessionExpired: 'Session expired: please login again',
  manageTemplatesV1: 'Please edit this template in manage template using v1',
  templateNotFound: 'Template Not Found'
};

export var someobj = function someobj(array, obj) {
  var result = false;
  array.map(function (item) {
    if (obj[Object.keys(obj)] === item[Object.keys(obj)]) {
      result = true;
      return 0;
    }
  });
  return result;
};

export var findobjIndex = function findobjIndex(array, obj) {
  var result = '';
  array.map(function (item, index) {
    if (typeof Object.values(obj)[0] === 'string') {
      if (obj[Object.keys(obj)] === item[Object.keys(obj)]) {
        result = index;
        return 0;
      }
    } else {
      if (obj.key === item) {
        result = index;
        return 0;
      }
    }
  });
  return result;
};

export var findobj = function findobj(array, obj) {
  var result = {};
  array.map(function (item, index) {
    if (obj[Object.keys(obj)] === item[Object.keys(obj)]) {
      result = item;
      return 0;
    }
  });
  return result;
};

export var channelKey = function channelKey(channels, channel) {
  var channelKey = 'default';
  for (var i = 0; i < channels.length; i++) {
    if (channels[i].value === channel) {
      return channels[i].key;
    }
  }
  return channelKey;
};

export var languageValue = function languageValue(languages, language) {
  var languageValue = '';
  for (var i = 0; i < languages.length; i++) {
    if (languages[i].key === language) {
      return languages[i].value;
    }
  }
  return languageValue;
};